@@ -9,7 +9,7 @@ use File::chdir;
 use File::Copy qw( copy );
 use base qw( Module::Build::FFI );
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 =head1 NAME
 
@@ -124,7 +124,8 @@ sub ffi_build_dynamic_lib
       exit 2 if $?;
     };
     
-    my($build_dll) = bsd_glob("$src_dir/target/release/*.$Config{dlext}");
+    my $dlext = $^O eq 'darwin' ? 'dylib' : $Config{dlext};
+    my($build_dll) = bsd_glob("$src_dir/target/release/*.$dlext");
     copy($build_dll, $dll) || do {
       print STDERR "copy failed for\n";
       print STDERR "  $build_dll => $dll\n";
